@@ -5,7 +5,8 @@ use base qw(
     CatalystX::CRUD
     Class::Accessor::Fast
 );
-use Class::C3;
+use MRO::Compat;
+use mro 'c3';
 use Carp;
 
 __PACKAGE__->mk_accessors(qw( model_name model_meta context app_class ));
